schema

package
v0.1.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 18, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetCurrentVersion

func GetCurrentVersion(db *sql.DB) (version int, err error)

Returns current schema version in the database

func GetLatestAvailableVersion

func GetLatestAvailableVersion() (latestVersion int, err error)

Returns latest available schema version available

func Purge

func Purge(db *sql.DB) (err error)

Purges the database schema (drops all tables)

func Upgrade

func Upgrade(db *sql.DB, targetVersion int) (err error)

Upgrades the database schema to the latest available version

func UpgradeToLatest added in v0.1.6

func UpgradeToLatest(db *sql.DB) error

Upgrades the database schema to the latest available version

Types

This section is empty.

Directories

Path Synopsis
test

Jump to